@@ -93,10 +93,10 @@ class Message(object):
                        PO file, if any
         :param context: the message context
         """
-        self.id = id #: The message ID
+        self.id = id
         if not string and self.pluralizable:
             string = (u'', u'')
-        self.string = string #: The message translation
+        self.string = string
         self.locations = list(distinct(locations))
         self.flags = set(flags)
         if id and self.python_format:
@@ -274,15 +274,15 @@ class Catalog(object):
         :param charset: the encoding to use in the output (defaults to utf-8)
         :param fuzzy: the fuzzy bit on the catalog header
         """
-        self.domain = domain #: The message domain
+        self.domain = domain
         if locale:
             locale = Locale.parse(locale)
-        self.locale = locale #: The locale or `None`
+        self.locale = locale
         self._header_comment = header_comment
         self._messages = odict()
 
-        self.project = project or 'PROJECT' #: The project name
-        self.version = version or 'VERSION' #: The project version
+        self.project = project or 'PROJECT'
+        self.version = version or 'VERSION'
         self.copyright_holder = copyright_holder or 'ORGANIZATION'
         self.msgid_bugs_address = msgid_bugs_address or 'EMAIL@ADDRESS'
 
@@ -297,15 +297,15 @@ class Catalog(object):
             creation_date = datetime.now(LOCALTZ)
         elif isinstance(creation_date, datetime) and not creation_date.tzinfo:
             creation_date = creation_date.replace(tzinfo=LOCALTZ)
-        self.creation_date = creation_date #: Creation date of the template
+        self.creation_date = creation_date
         if revision_date is None:
             revision_date = 'YEAR-MO-DA HO:MI+ZONE'
         elif isinstance(revision_date, datetime) and not revision_date.tzinfo:
             revision_date = revision_date.replace(tzinfo=LOCALTZ)
-        self.revision_date = revision_date #: Last revision date of the catalog
-        self.fuzzy = fuzzy #: Catalog header fuzzy bit (`True` or `False`)
+        self.revision_date = revision_date
+        self.fuzzy = fuzzy
 
-        self.obsolete = odict() #: Dictionary of obsolete messages
+        self.obsolete = odict()  # Dictionary of obsolete messages
         self._num_plurals = None
         self._plural_expr = None
 
@@ -331,7 +331,7 @@ class Catalog(object):
 
     >>> catalog = Catalog(project='Foobar', version='1.0',
     ...                   copyright_holder='Foo Company')
-    >>> print catalog.header_comment #doctest: +ELLIPSIS
+    >>> print(catalog.header_comment) #doctest: +ELLIPSIS
     # Translations template for Foobar.
     # Copyright (C) ... Foo Company
     # This file is distributed under the same license as the Foobar project.
@@ -349,7 +349,7 @@ class Catalog(object):
     ... # This file is distributed under the same license as the PROJECT
     ... # project.
     ... #'''
-    >>> print catalog.header_comment
+    >>> print(catalog.header_comment)
     # The POT for my really cool Foobar project.
     # Copyright (C) 1990-2003 Foo Company
     # This file is distributed under the same license as the Foobar
@@ -378,8 +378,8 @@ class Catalog(object):
             headers.append(('Language', str(self.locale)))
         if (self.locale is not None) and ('LANGUAGE' in self.language_team):
             headers.append(('Language-Team',
-                           self.language_team.replace('LANGUAGE',
-                                                      str(self.locale))))
+                            self.language_team.replace('LANGUAGE',
+                                                       str(self.locale))))
         else:
             headers.append(('Language-Team', self.language_team))
         if self.locale is not None:
@@ -433,7 +433,7 @@ class Catalog(object):
     >>> catalog = Catalog(project='Foobar', version='1.0',
     ...                   creation_date=created)
     >>> for name, value in catalog.mime_headers:
-    ...     print '%s: %s' % (name, value)
+    ...     print('%s: %s' % (name, value))
     Project-Id-Version: Foobar 1.0
     Report-Msgid-Bugs-To: EMAIL@ADDRESS
     POT-Creation-Date: 1990-04-01 15:30+0000
@@ -453,7 +453,7 @@ class Catalog(object):
     ...                   last_translator='John Doe <jd@example.com>',
     ...                   language_team='de_DE <de@example.com>')
     >>> for name, value in catalog.mime_headers:
-    ...     print '%s: %s' % (name, value)
+    ...     print('%s: %s' % (name, value))
     Project-Id-Version: Foobar 1.0
     Report-Msgid-Bugs-To: EMAIL@ADDRESS
     POT-Creation-Date: 1990-04-01 15:30+0000
@@ -673,7 +673,7 @@ class Catalog(object):
         if key in self._messages:
             del self._messages[key]
 
-    def update(self, template, no_fuzzy_matching=False):
+    def update(self, template, no_fuzzy_matching=False, update_header_comment=False):
         """Update the catalog based on the given template catalog.
 
         >>> from babel.messages import Catalog
@@ -720,7 +720,7 @@ class Catalog(object):
 
         >>> 'head' in catalog
         False
-        >>> catalog.obsolete.values()
+        >>> list(catalog.obsolete.values())
         [<Message 'head' (flags: [])>]
 
         :param template: the reference catalog, usually read from a POT file
@@ -779,7 +779,7 @@ class Catalog(object):
                     if no_fuzzy_matching is False:
                         # do some fuzzy matching with difflib
                         if isinstance(key, tuple):
-                            matchkey = key[0] # just the msgid, no context
+                            matchkey = key[0]  # just the msgid, no context
                         else:
                             matchkey = key
                         matches = get_close_matches(matchkey.lower().strip(),
@@ -797,6 +797,12 @@ class Catalog(object):
         for msgid in remaining:
             if no_fuzzy_matching or msgid not in fuzzy_matches:
                 self.obsolete[msgid] = remaining[msgid]
+
+        if update_header_comment:
+            # Allow the updated catalog's header to be rewritten based on the
+            # template's header
+            self.header_comment = template.header_comment
+
         # Make updated catalog's POT-Creation-Date equal to the template
         # used to update the catalog
         self.creation_date = template.creation_date
